package com.bonus.sgzb.base.service.impl;

import java.util.List;

import com.bonus.sgzb.base.api.domain.SysDic;
import com.bonus.sgzb.base.mapper.SysDicMapper;
import com.bonus.sgzb.base.service.ISysDicService;
import com.bonus.sgzb.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 数据字典Service业务层处理
 *
 * @author bonus
 * @date 2023-12-11
 */
@Service
public class SysDicServiceImpl implements ISysDicService
{
    @Autowired
    private SysDicMapper sysDicMapper;

    /**
     * 查询数据字典
     *
     * @param id 数据字典主键
     * @return 数据字典
     */
    @Override
    public SysDic selectSysDicById(Long id)
    {
        return sysDicMapper.selectSysDicById(id);
    }

    /**
     * 查询数据字典列表
     *
     * @param sysDic 数据字典
     * @return 数据字典
     */
    @Override
    public List<SysDic> selectSysDicList(SysDic sysDic)
    {
        return sysDicMapper.selectSysDicList(sysDic);
    }

    /**
     * 新增数据字典
     *
     * @param sysDic 数据字典
     * @return 结果
     */
    @Override
    public int insertSysDic(SysDic sysDic)
    {
        sysDic.setCreateTime(DateUtils.getNowDate());
        return sysDicMapper.insertSysDic(sysDic);
    }

    /**
     * 修改数据字典
     *
     * @param sysDic 数据字典
     * @return 结果
     */
    @Override
    public int updateSysDic(SysDic sysDic)
    {
        return sysDicMapper.updateSysDic(sysDic);
    }

    /**
     * 批量删除数据字典
     *
     * @param ids 需要删除的数据字典主键
     * @return 结果
     */
    @Override
    public int deleteSysDicByIds(Long[] ids)
    {
        return sysDicMapper.deleteSysDicByIds(ids);
    }

    /**
     * 删除数据字典信息
     *
     * @param id 数据字典主键
     * @return 结果
     */
    @Override
    public int deleteSysDicById(Long id)
    {
        return sysDicMapper.deleteSysDicById(id);
    }
}
